@@ -1,21 +1,10 @@
-/***************************************************************************
-                        Vocabulary Expression for KDE Edu
-    -----------------------------------------------------------------------
-    copyright      : (C) 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
-
-                     (C) 2005-2007 Peter Hedlund <peter.hedlund@kdemail.net>
-    Copyright 2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-
+/*
+ * Vocabulary Expression for KDE Edu
+ * SPDX-FileCopyrightText: 1999-2001 Ewald Arnold <kvoctrain@ewald-arnold.de>
+ * SPDX-FileCopyrightText: 2005-2007 Peter Hedlund <peter.hedlund@kdemail.net>
+ * SPDX-FileCopyrightText: 2008 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+ * SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "keduvocexpression.h"
 
