@@ -1,26 +1,8 @@
-/***************************************************************************
-
-    C++ Implementation: keduvockvtml1compability_p
-
-    -----------------------------------------------------------------------
-
-    begin         : Di Aug 28 2007
-
-    copyright     : (C) 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
-
-    -----------------------------------------------------------------------
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-
+/*
+ * C++ Implementation: keduvockvtml1compability_p
+ * SPDX-FileCopyrightText: 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
+ * SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "keduvockvtmlcompability.h"
 #include "keduvocwordtype.h"
 
@@ -172,7 +154,6 @@ if ( oldType.length() >= 2 && type.left( 1 ) == QM_USER_TYPE ) {
 */
 
 
-
 void KEduVocKvtmlCompability::initOldTenses()
 {
     m_oldTenses[QStringLiteral("PrSi")] = i18n( "Simple Present" );
